@@ -38,7 +38,7 @@ from ..wkt import WKTTransformer
 logger.setLevel(logging.DEBUG)
 
 
-@v_args(inline=True)
+@v_args(meta=False, inline=True)
 class CQLTransformer(WKTTransformer, ISO8601Transformer):
     def and_(self, *args):
         return ast.And.from_items(*args)
@@ -202,6 +202,7 @@ parser = Lark.open(
     rel_to=__file__,
     parser="lalr",
     debug=True,
+    maybe_placeholders=False,
     transformer=CQLTransformer(),
     import_paths=[os.path.dirname(os.path.dirname(__file__))],
 )
